Module api

Module api 

Structs

Fcmdata
Central instance to access all Fcmdata related resource activities
GoogleFirebaseFcmDataV1beta1AndroidDeliveryData
Message delivery data for a given date, app, and analytics label combination.
GoogleFirebaseFcmDataV1beta1Data
Data detailing messaging delivery
GoogleFirebaseFcmDataV1beta1DeliveryPerformancePercents
Overview of delivery performance for messages that were successfully delivered. All percentages are calculated with countMessagesAccepted as the denominator. These categories are not mutually exclusive; a message can be delayed for multiple reasons.
GoogleFirebaseFcmDataV1beta1ListAndroidDeliveryDataResponse
Response message for ListAndroidDeliveryData.
GoogleFirebaseFcmDataV1beta1MessageInsightPercents
Additional information about message delivery. All percentages are calculated with countMessagesAccepted as the denominator.
GoogleFirebaseFcmDataV1beta1MessageOutcomePercents
Percentage breakdown of message delivery outcomes. These categories are mutually exclusive. All percentages are calculated with countMessagesAccepted as the denominator. These categories may not account for all message outcomes.
GoogleFirebaseFcmDataV1beta1ProxyNotificationInsightPercents
Additional information about proxy notification delivery. All percentages are calculated with countNotificationsAccepted as the denominator.
GoogleTypeDate
Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type.TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
ProjectAndroidAppDeliveryDataListCall
List aggregate delivery data for the given Android application.
ProjectMethods
A builder providing access to all methods supported on project resources. It is not used directly, but through the Fcmdata hub.

Enums

Scope
Identifies the an OAuth2 authorization scope. A scope is needed when requesting an authorization token.