pub struct GoogleFirebaseFcmDataV1beta1AndroidDeliveryData {
pub analytics_label: Option<String>,
pub app_id: Option<String>,
pub data: Option<GoogleFirebaseFcmDataV1beta1Data>,
pub date: Option<GoogleTypeDate>,
}Expand description
Message delivery data for a given date, app, and analytics label combination.
This type is not used in any activity, and only used as part of another schema.
Fields
analytics_label: Option<String>The analytics label associated with the messages sent. All messages sent without an analytics label will be grouped together in a single entry.
app_id: Option<String>The app ID to which the messages were sent.
data: Option<GoogleFirebaseFcmDataV1beta1Data>The data for the specified appId, date, and analyticsLabel.
date: Option<GoogleTypeDate>The date represented by this entry.