pub struct GoogleFirebaseFcmDataV1beta1Data {
pub count_messages_accepted: Option<i64>,
pub count_notifications_accepted: Option<i64>,
pub delivery_performance_percents: Option<GoogleFirebaseFcmDataV1beta1DeliveryPerformancePercents>,
pub message_insight_percents: Option<GoogleFirebaseFcmDataV1beta1MessageInsightPercents>,
pub message_outcome_percents: Option<GoogleFirebaseFcmDataV1beta1MessageOutcomePercents>,
pub proxy_notification_insight_percents: Option<GoogleFirebaseFcmDataV1beta1ProxyNotificationInsightPercents>,
}Expand description
Data detailing messaging delivery
This type is not used in any activity, and only used as part of another schema.
Fields
count_messages_accepted: Option<i64>Count of messages accepted by FCM intended for Android devices. The targeted device must have opted in to the collection of usage and diagnostic information.
count_notifications_accepted: Option<i64>Count of notifications accepted by FCM intended for Android devices. The targeted device must have opted in to the collection of usage and diagnostic information.
delivery_performance_percents: Option<GoogleFirebaseFcmDataV1beta1DeliveryPerformancePercents>Additional information about delivery performance for messages that were successfully delivered.
message_insight_percents: Option<GoogleFirebaseFcmDataV1beta1MessageInsightPercents>Additional general insights about message delivery.
message_outcome_percents: Option<GoogleFirebaseFcmDataV1beta1MessageOutcomePercents>Mutually exclusive breakdown of message delivery outcomes.
proxy_notification_insight_percents: Option<GoogleFirebaseFcmDataV1beta1ProxyNotificationInsightPercents>Additional insights about proxy notification delivery.