pub struct GoogleFirebaseFcmDataV1beta1DeliveryPerformancePercents {
pub delayed_device_doze: Option<f32>,
pub delayed_device_offline: Option<f32>,
pub delayed_message_throttled: Option<f32>,
pub delayed_user_stopped: Option<f32>,
pub delivered_no_delay: Option<f32>,
}Expand description
Overview of delivery performance for messages that were successfully delivered. All percentages are calculated with countMessagesAccepted as the denominator. These categories are not mutually exclusive; a message can be delayed for multiple reasons.
This type is not used in any activity, and only used as part of another schema.
Fields
delayed_device_doze: Option<f32>The percentage of accepted messages that were delayed because the device was in doze mode. Only normal priority messages should be delayed due to doze mode.
delayed_device_offline: Option<f32>The percentage of accepted messages that were delayed because the target device was not connected at the time of sending. These messages were eventually delivered when the device reconnected.
delayed_message_throttled: Option<f32>The percentage of accepted messages that were delayed due to message throttling, such as collapsible message throttling or maximum message rate throttling.
delayed_user_stopped: Option<f32>The percentage of accepted messages that were delayed because the intended device user-profile was stopped on the target device at the time of the send. The messages were eventually delivered when the user-profile was started again.
delivered_no_delay: Option<f32>The percentage of accepted messages that were delivered to the device without delay from the FCM system.