GoogleFirebaseFcmDataV1beta1MessageOutcomePercents

Struct GoogleFirebaseFcmDataV1beta1MessageOutcomePercents 

pub struct GoogleFirebaseFcmDataV1beta1MessageOutcomePercents {
    pub collapsed: Option<f32>,
    pub delivered: Option<f32>,
    pub dropped_app_force_stopped: Option<f32>,
    pub dropped_device_inactive: Option<f32>,
    pub dropped_too_many_pending_messages: Option<f32>,
    pub dropped_ttl_expired: Option<f32>,
    pub pending: Option<f32>,
}
Percentage breakdown of message delivery outcomes. These categories are mutually exclusive. All percentages are calculated with countMessagesAccepted as the denominator. These categories may not account for all message outcomes.

This type is not used in any activity, and only used as part of another schema.

Fields

collapsed: Option<f32>

The percentage of accepted messages that were collapsed by another message.

delivered: Option<f32>

The percentage of all accepted messages that were successfully delivered to the device.

dropped_app_force_stopped: Option<f32>

The percentage of accepted messages that were dropped because the application was force stopped on the device at the time of delivery and retries were unsuccessful.

dropped_device_inactive: Option<f32>

The percentage of accepted messages that were dropped because the target device is inactive. FCM will drop messages if the target device is deemed inactive by our servers. If a device does reconnect, we call OnDeletedMessages() in our SDK instead of delivering the messages.

dropped_too_many_pending_messages: Option<f32>

The percentage of accepted messages that were dropped due to too many undelivered non-collapsible messages. Specifically, each app instance can only have 100 pending messages stored on our servers for a device which is disconnected. When that device reconnects, those messages are delivered. When there are more than the maximum pending messages, we call OnDeletedMessages() in our SDK instead of delivering the messages.

dropped_ttl_expired: Option<f32>

The percentage of accepted messages that expired because Time To Live (TTL) elapsed before the target device reconnected.

pending: Option<f32>

The percentage of messages accepted on this day that were not dropped and not delivered, due to the device being disconnected (as of the end of the America/Los_Angeles day when the message was sent to FCM). A portion of these messages will be delivered the next day when the device connects but others may be destined to devices that ultimately never reconnect.