pub struct GoogleFirebaseFcmDataV1beta1MessageInsightPercents {
pub priority_lowered: Option<f32>,
}Expand description
Additional information about message delivery. All percentages are calculated with countMessagesAccepted as the denominator.
This type is not used in any activity, and only used as part of another schema.
Fields
priority_lowered: Option<f32>The percentage of accepted messages that had their priority lowered from high to normal. See documentation for setting message priority.