pub struct GoogleFirebaseFcmDataV1beta1ProxyNotificationInsightPercents {
pub failed: Option<f32>,
pub proxied: Option<f32>,
pub skipped_not_throttled: Option<f32>,
pub skipped_opted_out: Option<f32>,
pub skipped_unconfigured: Option<f32>,
pub skipped_unsupported: Option<f32>,
}Expand description
Additional information about proxy notification delivery. All percentages are calculated with countNotificationsAccepted as the denominator.
This type is not used in any activity, and only used as part of another schema.
Fields
failed: Option<f32>The percentage of accepted notifications that failed to be proxied. This is usually caused by exceptions that occurred while calling notifyAsPackage.
proxied: Option<f32>The percentage of accepted notifications that were successfully proxied by Google Play services.
skipped_not_throttled: Option<f32>The percentage of accepted notifications that were skipped because the messages were not throttled.
skipped_opted_out: Option<f32>The percentage of accepted notifications that were skipped because the app disallowed these messages to be proxied.
skipped_unconfigured: Option<f32>The percentage of accepted notifications that were skipped because configurations required for notifications to be proxied were missing.
skipped_unsupported: Option<f32>The percentage of accepted notifications that were skipped because proxy notification is unsupported for the recipient.